import numpy as np
import kubric as kb
asset_source = kb.AssetSource("/assets/KuBasic")
scene = kb.Scene(resolution=(640, 640))
renderer = kb.renderer.Blender(scene)
simulator = kb.simulator.PyBullet(scene)
# --- populate the scene
scene.camera = kb.PerspectiveCamera(position=(0, 5, 5), 
                                    look_at=(0, 0, 0))
scene += kb.Cube(name="floor", scale=(10, 10, .1), 
                 position=(0, 0, -0.1), static=True)
scene += kb.PointLight(position=(-2.5, -1, 5), intensity=300)
rng = np.random.RandomState(seed=42)
for i in range(8): # place 8 random objects within a region
  mat = kb.PrincipledBSDFMaterial(color=kb.random_hue_color(rng=rng),
                                  metallic=rng.choice([0.0, 1.0]),
                                  transmission=rng.choice([0.0, 1.0]))
  obj = asset_source.create(rng.choice(asset_source.all_asset_ids),
                            material=mat, velocity=rng.normal(size=3))
  scene += obj
  kb.move_until_no_overlap(obj, simulator, rng=rng,
                           spawn_region=[[-1, -1, 0], [1, 1, 1]])
# --- execute the simulation, render, and save data to files
simulator.run()
renderer.save_state("output/scene.blend")
frames_dict = renderer.render()
kb.write_image_dict(frames_dict, "output")
kb.write_json({"camera": kb.get_camera_info(scene.camera),
               "instances": kb.get_instance_info(scene)},
              filename="output/metadata.json")